@@ -4,6 +4,7 @@ import oschmod
 import gzip
 import re
 import yaml
+import resource
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_datetime
 from qualys_etl.etld_lib import etld_lib_sqlite_tables
@@ -172,6 +173,7 @@ global asset_inventory_http_conn_timeout
 global asset_inventory_open_file_compression_method
 global asset_inventory_test_system_flag
 global asset_inventory_test_number_of_files_to_extract
+global asset_inventory_last_seen_asset_id_for_restart
 
 # test system global variables
 global test_system_log_file
@@ -623,7 +625,7 @@ def get_kb_user_config():
         get_attribute_from_config_settings('kb_truncation_limit', '0')
     kb_chunk_size_calc = int(get_attribute_from_config_settings('kb_chunk_size_calc', '20480'))
     kb_try_extract_max_count = int(get_attribute_from_config_settings('kb_try_extract_max_count', '30'))
-    kb_http_conn_timeout = int(get_attribute_from_config_settings('kb_http_conn_timeout', '300'))
+    kb_http_conn_timeout = int(get_attribute_from_config_settings('kb_http_conn_timeout', '900'))
     kb_open_file_compression_method = \
         get_open_file_compression_method_from_config_settings('kb_open_file_compression_method')
 
@@ -751,7 +753,7 @@ def get_host_list_user_config():
     host_list_present_csv_cell_as_json = get_attribute_from_config_settings('host_list_present_csv_cell_as_json', True)
     host_list_chunk_size_calc = int(get_attribute_from_config_settings('host_list_chunk_size_calc', '20480'))
     host_list_try_extract_max_count = int(get_attribute_from_config_settings('host_list_try_extract_max_count', '30'))
-    host_list_http_conn_timeout = int(get_attribute_from_config_settings('host_list_http_conn_timeout', '300'))
+    host_list_http_conn_timeout = int(get_attribute_from_config_settings('host_list_http_conn_timeout', '900'))
     host_list_open_file_compression_method = \
         get_open_file_compression_method_from_config_settings('host_list_open_file_compression_method')
     host_list_test_system_flag = \
@@ -904,6 +906,17 @@ def get_host_list_detection_user_config():
             etld_lib_functions.logger.info(
                 f" user select batch_size_max was {host_list_detection_multi_proc_batch_size}.")
             host_list_detection_multi_proc_batch_size = 2000
+        elif int(host_list_detection_multi_proc_batch_size) > 100:
+            etld_lib_functions.logger.info(f"reset batch_size_max to {host_list_detection_multi_proc_batch_size}.")
+            etld_lib_functions.logger.info(
+                f" user select batch_size_max is {host_list_detection_multi_proc_batch_size}.")
+            host_list_detection_multi_proc_batch_size = int(host_list_detection_multi_proc_batch_size)
+        else:
+            etld_lib_functions.logger.info(f"reset batch_size_max to 100.")
+            etld_lib_functions.logger.info(f" user select batch_size_max is "
+                                           f"{host_list_detection_multi_proc_batch_size},"
+                                           f"but is not within range. 100 - 2000.  Reset to 100")
+            host_list_detection_multi_proc_batch_size = 100
 
         host_list_detection_limit_hosts = \
             get_attribute_from_config_settings('host_list_detection_limit_hosts', '0')
@@ -928,7 +941,7 @@ def get_host_list_detection_user_config():
     host_list_detection_try_extract_max_count = \
         int(get_attribute_from_config_settings('host_list_detection_try_extract_max_count', '30'))
     host_list_detection_http_conn_timeout = \
-        int(get_attribute_from_config_settings('host_list_detection_http_conn_timeout', '300'))
+        int(get_attribute_from_config_settings('host_list_detection_http_conn_timeout', '900'))
     host_list_detection_open_file_compression_method = \
         get_open_file_compression_method_from_config_settings('host_list_detection_open_file_compression_method')
 
@@ -1002,6 +1015,7 @@ def get_asset_inventory_user_config():
     global asset_inventory_open_file_compression_method
     global asset_inventory_test_system_flag
     global asset_inventory_test_number_of_files_to_extract
+    global asset_inventory_last_seen_asset_id_for_restart
 
     def set_asset_inventory_last_updated():
         global asset_inventory_asset_last_updated
@@ -1037,12 +1051,14 @@ def get_asset_inventory_user_config():
     asset_inventory_try_extract_max_count = \
         int(get_attribute_from_config_settings('asset_inventory_try_extract_max_count', '30'))
     asset_inventory_http_conn_timeout = \
-        int(get_attribute_from_config_settings('asset_inventory_http_conn_timeout', '300'))
+        int(get_attribute_from_config_settings('asset_inventory_http_conn_timeout', '900'))
     asset_inventory_open_file_compression_method = \
         get_open_file_compression_method_from_config_settings('asset_inventory_open_file_compression_method')
     asset_inventory_test_system_flag = get_attribute_from_config_settings('asset_inventory_test_system_flag', False)
     asset_inventory_test_number_of_files_to_extract = \
         get_attribute_from_config_settings('asset_inventory_test_number_of_files_to_extract', 3)
+    asset_inventory_last_seen_asset_id_for_restart = \
+        get_attribute_from_config_settings('asset_inventory_last_seen_asset_id_for_restart', 0)
     set_asset_inventory_last_updated()
 
     etld_lib_functions.logger.info(f"asset inventory config - {qetl_user_config_settings_yaml_file}")
@@ -1168,7 +1184,7 @@ def get_was_user_config():
     was_try_extract_max_count = \
         int(get_attribute_from_config_settings('was_try_extract_max_count', '30'))
     was_http_conn_timeout = \
-        int(get_attribute_from_config_settings('was_http_conn_timeout', '300'))
+        int(get_attribute_from_config_settings('was_http_conn_timeout', '900'))
     was_open_file_compression_method = \
         get_open_file_compression_method_from_config_settings('was_open_file_compression_method')
     was_test_system_flag = get_attribute_from_config_settings('was_test_system_flag', False)
@@ -1290,8 +1306,10 @@ def host_list_csv_columns():  # Return list of csv columns
         'CLOUD_SERVICE', 'CLOUD_RESOURCE_ID', 'EC2_INSTANCE_ID', 'NETBIOS', 'OS', 'QG_HOSTID', 'TAGS', 'METADATA',
         'CLOUD_PROVIDER_TAGS', 'LAST_VULN_SCAN_DATETIME', 'LAST_VM_SCANNED_DATE', 'LAST_VM_SCANNED_DURATION',
         'LAST_VM_AUTH_SCANNED_DATE', 'LAST_VM_AUTH_SCANNED_DURATION', 'LAST_COMPLIANCE_SCAN_DATETIME', 'OWNER',
-        'COMMENTS', 'USER_DEF', 'ASSET_GROUP_IDS', 'BATCH_DATE', 'BATCH_NUMBER'
+        'COMMENTS', 'USER_DEF', 'ASSET_GROUP_IDS', 'ASSET_RISK_SCORE', 'ASSET_CRITICALITY_SCORE', 'ARS_FACTORS',
+        'BATCH_DATE', 'BATCH_NUMBER'
     ]
+
     return csv_columns
 
 
@@ -1353,6 +1371,7 @@ def host_list_detection_qids_csv_columns():  # Return list of csv columns
                    'LAST_TEST_DATETIME', 'LAST_UPDATE_DATETIME', 'LAST_FIXED_DATETIME', 'FIRST_REOPENED_DATETIME',
                    'LAST_REOPENED_DATETIME', 'TIMES_REOPENED', 'SERVICE', 'IS_IGNORED', 'IS_DISABLED',
                    'AFFECT_RUNNING_KERNEL', 'AFFECT_RUNNING_SERVICE', 'AFFECT_EXPLOITABLE_CONFIG',
+                   'QDS', 'QDS_FACTORS',
                    'RESULTS', 'BATCH_DATE', 'BATCH_NUMBER'
                   ]
     return csv_columns
@@ -1438,6 +1457,25 @@ def status_table_csv_column_types():
     return csv_columns
 
 
+def set_limit_open_files_to_hard_limit_for_multiprocessing_pipes(module_function="limit_open_files", logger_method=print):
+    # Host List Detection accumulates pipes open during processing.
+    # Until addressed, ensure open files is set to hard limit.
+    limit_soft, limit_hard = resource.getrlimit(resource.RLIMIT_NOFILE)
+    logger_method(f"limit_open_files before: {module_function} limit_soft={limit_soft}, limit_hard={limit_hard}")
+    resource.setrlimit(resource.RLIMIT_NOFILE, (limit_hard, limit_hard))
+    limit_soft, limit_hard = resource.getrlimit(resource.RLIMIT_NOFILE)
+    logger_method(f"limit_open_files after:  {module_function} limit_soft={limit_soft}, limit_hard={limit_hard}")
+
+
+def log_ram_disk_stats():
+    etld_lib_functions.log_system_information(
+        data_directory=qetl_user_home_dir,
+        logger_method=etld_lib_functions.logger.info)
+    etld_lib_functions.if_disk_space_usage_greater_than_90_log_warning(
+        data_directory=qetl_user_home_dir,
+        logger_method=etld_lib_functions.logger.warn)
+
+
 def main():
     get_qetl_code_dir()
     setup_user_home_directories()
@@ -1461,6 +1499,8 @@ def main():
 
     setup_test_system_vars()
 
+    set_limit_open_files_to_hard_limit_for_multiprocessing_pipes(logger_method=etld_lib_functions.logger.info)
+    log_ram_disk_stats()
     setup_completed()
 
 
