@@ -7,6 +7,7 @@ import time
 import getpass
 import dbm
 import dbm.gnu
+import psutil
 from os.path import exists
 import re
 from pathlib import Path
@@ -334,6 +335,142 @@ class DisplayCounterToLog:
             self.logger_func(f"{self.display_counter_log_message} - Total: {self.counter:,}")
 
 
+def log_system_information(logger_method=print, data_directory="/opt/qetl/users"):
+    logger_method(
+        f'SYS STAT: CPU percent usage={psutil.cpu_percent(interval=0.5)}, '
+        f'frequency='
+        f'{get_cpu_frequency()}%, '
+        f'count='
+        f'{get_cpu_count()}, '
+    )
+    logger_method(
+        f'SYS STAT: RAM percent usage='
+        f'{get_ram_usage_pct()}, '
+        f'total='
+        f'{get_ram_size_total_in_mb():,.0f} MB, '
+        f'used='
+        f'{get_ram_size_usage_in_mb():,.0f} MB, '
+        f'available='
+        f'{get_ram_size_available_in_mb():,.0f} MB, '
+    )
+    logger_method(
+        f'SYS STAT: SWAP percent usage='
+        f'{get_swap_usage_pct()}, '
+        f'total='
+        f'{get_swap_total_in_mb():,.0f} MB, '
+        f'used='
+        f'{get_swap_usage_in_mb():,.0f} MB, '
+        f'available='
+        f'{get_swap_available_in_mb():,.0f} MB, '
+    )
+
+    try:
+        logger_method(
+            f'SYS STAT: DISK percent usage='
+            f'{get_disk_size_pct(data_dir=data_directory)}, '
+            f'total='
+            f'{get_disk_size_total(data_dir=data_directory):,.0f} MB, '
+            f'used='
+            f'{get_disk_size_usage(data_dir=data_directory):,.0f} MB, '
+            f'available='
+            f'{get_disk_size_remaining(data_dir=data_directory):,.0f} MB, '
+            f'path='
+            f'{data_directory}, '
+        )
+    except Exception as e:
+        pass
+
+
+def if_disk_space_usage_greater_than_90_log_warning(logger_method=print, data_directory="/opt/qetl/users"):
+    try:
+        disk_size_usage_pct = int(get_disk_size_pct(data_dir=data_directory))
+        if disk_size_usage_pct > 90:
+            logger_method(f'SYS WARNING: DISK percent usage > 90% at {disk_size_usage_pct}%')
+    except Exception as e:
+        pass
+
+
+def if_ram_space_size_less_than_8_gig_log_warning(logger_method=print):
+    ram_size_total_in_mb = int(get_ram_size_total_in_mb())
+    if ram_size_total_in_mb < 8100:
+        logger_method(f'SYS WARNING: DISK size usage < 8 Gig.  Consider increasing RAM to 16 Gig for ETL')
+
+
+def proc_table(logger_method=print):
+    for proc in psutil.process_iter(['pid', 'name']):
+        if 'python' in proc.info['name']:
+            p = psutil.Process(proc.pid)
+            #p.open_files().count()
+            logger_method(f'SYS STAT: PID COMMAND={proc.pid}, OPEN_FILES={p.open_files()}, CMD={p.cmdline()}')
+            logger_method(f'PID STAT: PID CHILDREN={proc.pid}, CHILDREN={p.children(recursive=True)}')
+
+
+def get_disk_size_pct(data_dir="/opt/qetl/users"):
+    return psutil.disk_usage(data_dir).percent
+
+
+def get_disk_size_total(data_dir="/opt/qetl/users"):
+    return psutil.disk_usage(data_dir).total / 1024 / 1024
+
+
+def get_disk_size_usage(data_dir="/opt/qetl/users"):
+    return psutil.disk_usage(data_dir).used / 1024 / 1024
+
+
+def get_disk_size_remaining(data_dir="/opt/qetl/users"):
+    total_disk_space = psutil.disk_usage(data_dir).total / 1024 / 1024
+    used_disk_space = psutil.disk_usage(data_dir).used / 1024 / 1024
+    available_disk_space = total_disk_space - used_disk_space
+    return available_disk_space
+
+
+def get_cpu_usage_pct():
+    return psutil.cpu_percent(interval=0.5)
+
+
+def get_cpu_frequency():
+    return int(psutil.cpu_freq().current)
+
+
+def get_cpu_count():
+    return int(psutil.cpu_count())
+
+
+def get_ram_size_usage_in_mb():
+    return int(psutil.virtual_memory().total - psutil.virtual_memory().available) / 1024 / 1024
+
+
+def get_ram_size_total_in_mb():
+    return int(psutil.virtual_memory().total) / 1024 / 1024
+
+
+def get_ram_usage_pct():
+    return psutil.virtual_memory().percent
+
+
+def get_ram_size_available_in_mb():
+    return int(psutil.virtual_memory().available) / 1024 / 1034
+
+
+def get_swap_usage_in_mb():
+    return int(psutil.swap_memory().used) / 1024 / 1024
+
+
+def get_swap_total_in_mb():
+    return int(psutil.swap_memory().total) / 1024 / 1024
+
+
+def get_swap_available_in_mb():
+    total_swap_space = psutil.swap_memory().total / 1024 / 1024
+    used_swap_space = psutil.swap_memory().used / 1024 / 1024
+    available_swap_space = total_swap_space - used_swap_space
+    return available_swap_space
+
+
+def get_swap_usage_pct():
+    return psutil.swap_memory().percent
+
+
 def main(log_level=logging.INFO, my_logger_prog_name=None):
     global logging_level
     setup_logging_stdout(log_level, my_logger_prog_name)
